pub struct SphereFile<C> {
pub sphere_identity: Did,
pub sphere_version: Link<MemoIpld>,
pub memo_version: Link<MemoIpld>,
pub memo: MemoIpld,
pub contents: C,
}Expand description
A descriptor for contents that is stored in a sphere.
Fields
sphere_identity: DidThe identity of the associated sphere from which the file was read
sphere_version: Link<MemoIpld>The version of the associated sphere from which the file was read
memo_version: Link<MemoIpld>The version of the memo that wraps the file’s body contents
memo: MemoIpldThe memo that wraps the file’s body contents
contents: CThe body contents of the file
Implementations
Sourceimpl<C> SphereFile<C>where
C: AsyncFileBody + 'static,
impl<C> SphereFile<C>where
C: AsyncFileBody + 'static,
Sourcepub fn boxed(self) -> SphereFile<Pin<Box<dyn AsyncFileBody + 'static>>>
pub fn boxed(self) -> SphereFile<Pin<Box<dyn AsyncFileBody + 'static>>>
Consume the file and return a version of it where its body contents have been boxed and pinned